summaryrefslogtreecommitdiffstats
path: root/bibletime/frontend/display/cplainwritedisplay.h
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/frontend/display/cplainwritedisplay.h')
-rw-r--r--bibletime/frontend/display/cplainwritedisplay.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/bibletime/frontend/display/cplainwritedisplay.h b/bibletime/frontend/display/cplainwritedisplay.h
index 9219578..546d05c 100644
--- a/bibletime/frontend/display/cplainwritedisplay.h
+++ b/bibletime/frontend/display/cplainwritedisplay.h
@@ -16,8 +16,8 @@
#include "cwritedisplay.h"
//Qt includes
-#include <qwidget.h>
-#include <qtextedit.h>
+#include <tqwidget.h>
+#include <tqtextedit.h>
class CHTMLWriteDisplay;
class KAction;
@@ -25,7 +25,7 @@ class KAction;
/** The write display implementation for plain source code editing.
* @author The BibleTime team
*/
-class CPlainWriteDisplay : public QTextEdit, public CWriteDisplay {
+class CPlainWriteDisplay : public TQTextEdit, public CWriteDisplay {
public:
/**
* Reimplementation.
@@ -34,7 +34,7 @@ public:
/**
* Sets the new text for this display widget.
*/
- virtual void setText( const QString& newText );
+ virtual void setText( const TQString& newText );
/**
* Returns true if the display widget has a selection. Otherwise false.
*/
@@ -42,8 +42,8 @@ public:
/**
* Returns the view of this display widget.
*/
- virtual QWidget* view();
- virtual const QString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
+ virtual TQWidget* view();
+ virtual const TQString text( const CDisplay::TextType format = CDisplay::HTMLText, const CDisplay::TextPart part = CDisplay::Document );
virtual void print( const CDisplay::TextPart, CSwordBackend::DisplayOptions displayOptions, CSwordBackend::FilterOptions filterOptions );
/**
* Reimplementation.
@@ -56,7 +56,7 @@ public:
/**
* Returns the text of this edit widget.
*/
- virtual const QString plainText();
+ virtual const TQString plainText();
/**
* Creates the necessary action objects and puts them on the toolbar.
*/
@@ -66,28 +66,28 @@ protected:
friend class CDisplay;
friend class CHTMLWriteDisplay;
- CPlainWriteDisplay(CWriteWindow* parentWindow, QWidget* parent);
+ CPlainWriteDisplay(CWriteWindow* parentWindow, TQWidget* parent);
virtual ~CPlainWriteDisplay();
/**
* Reimplementation from QTextEdit. Provides an popup menu for the given position.
*/
- virtual QPopupMenu* createPopupMenu( const QPoint& pos );
+ virtual TQPopupMenu* createPopupMenu( const TQPoint& pos );
/**
* Reimplementation from QTextEdit. Provides an popup menu.
*/
- virtual QPopupMenu* createPopupMenu();
+ virtual TQPopupMenu* createPopupMenu();
/**
* Reimplementation to manage drops of our drag and drop objects.
*/
- virtual void contentsDropEvent( QDropEvent* e );
+ virtual void contentsDropEvent( TQDropEvent* e );
/**
* Reimplementation to insert the text of a dragged reference into the edit view.
*/
- virtual void contentsDragEnterEvent( QDragEnterEvent* e );
+ virtual void contentsDragEnterEvent( TQDragEnterEvent* e );
/**
* Reimplementation to insert the text of a dragged reference into the edit view.
*/
- virtual void contentsDragMoveEvent( QDragMoveEvent* e );
+ virtual void contentsDragMoveEvent( TQDragMoveEvent* e );
};
@@ -66,28 +66,28 @@ protected:
virtual ~CPlainWriteDisplay();
/**
- * Reimplementation from QTextEdit. Provides an popup menu for the given position.
+ * Reimplementation from TQTextEdit. Provides an popup menu for the given position.
*/
@@ -66,28 +66,28 @@ protected:
/**
- * Reimplementation from QTextEdit. Provides an popup menu.
+ * Reimplementation from TQTextEdit. Provides an popup menu.
*/